"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireWildcard(require("react"));

var _ActionButton = _interopRequireDefault(require("../ActionButton"));

var _Sort = _interopRequireDefault(require("./Sort"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _Drawer = _interopRequireDefault(require("../drawer/Drawer"));

var _Menu = _interopRequireDefault(require("@material-ui/core/Menu"));

var _useMediaQuery = _interopRequireDefault(require("@material-ui/core/useMediaQuery"));

var _styles = require("@material-ui/core/styles");

var _router = require("next/router");

var _SearchResultsContext = _interopRequireDefault(require("./SearchResultsContext"));

/**
 * A button that when clicked, opens a drawer containing the `Sort` view. The name of the currently
 * selected sortOption is display in the button text.
 */
function SortButton(_ref) {
  var variant = _ref.variant,
      title = _ref.title,
      drawerProps = _ref.drawerProps,
      onClick = _ref.onClick,
      sortProps = _ref.sortProps,
      drawerBreakpoint = _ref.drawerBreakpoint,
      href = _ref.href,
      props = (0, _objectWithoutProperties2["default"])(_ref, ["variant", "title", "drawerProps", "onClick", "sortProps", "drawerBreakpoint", "href"]);
  var theme = (0, _styles.useTheme)();
  var openSort = (0, _router.useRouter)().query.openSort === '1';

  var _useState = (0, _react.useState)({
    open: false,
    mountDrawer: false,
    anchorEl: null
  }),
      _useState2 = (0, _slicedToArray2["default"])(_useState, 2),
      state = _useState2[0],
      setState = _useState2[1];

  var open = state.open,
      mountDrawer = state.mountDrawer,
      anchorEl = state.anchorEl;

  var _useContext = (0, _react.useContext)(_SearchResultsContext["default"]),
      _useContext$pageData = _useContext.pageData,
      sort = _useContext$pageData.sort,
      sortOptions = _useContext$pageData.sortOptions;

  var buttonRef = (0, _react.useRef)();
  var selectedOption = sortOptions.find(function (o) {
    return sort === o.code;
  });
  (0, _react.useEffect)(function () {
    if (location.search.indexOf('openSort') !== -1) {
      setState({
        open: true,
        mountDrawer: true,
        anchorEl: buttonRef.current
      });
    }
  }, []);

  var handleClick = function handleClick(e) {
    if (onClick) {
      onClick(e);
    }

    if (!e.defaultPrevented) {
      toggleOpen(true, e.currentTarget);
    }
  };

  var close = function close() {
    toggleOpen(false);
  };

  var toggleOpen = function toggleOpen(open, anchorEl) {
    if (open) {
      setState({
        mountDrawer: true,
        open: true,
        anchorEl: anchorEl
      });
    } else {
      setState({
        open: false,
        anchorEl: null
      });
    }
  };

  var useDrawer = (0, _useMediaQuery["default"])(theme.breakpoints.down(drawerBreakpoint));
  return _react["default"].createElement(_react["default"].Fragment, null, _react["default"].createElement(_ActionButton["default"], (0, _extends2["default"])({
    key: "button",
    label: title,
    ref: buttonRef,
    value: selectedOption && selectedOption.name,
    href: href
  }, props, {
    onClick: function onClick(e) {
      return handleClick(e);
    }
  })), !href && useDrawer && _react["default"].createElement(_Drawer["default"], (0, _extends2["default"])({
    ModalProps: {
      keepMounted: true
    },
    key: "drawer",
    anchor: "bottom",
    title: title,
    open: open,
    onClose: close
  }, drawerProps), mountDrawer && _react["default"].createElement(_Sort["default"], (0, _extends2["default"])({
    onSelect: close
  }, sortProps))), !href && !useDrawer && _react["default"].createElement(_Menu["default"], {
    open: open,
    anchorEl: anchorEl,
    onClose: close
  }, _react["default"].createElement(_Sort["default"], (0, _extends2["default"])({
    variant: "menu-items",
    onSelect: close
  }, sortProps))));
}

SortButton.propTypes = {
  /**
   * CSS classes
   */
  classes: _propTypes["default"].object,

  /**
   * Props to pass to the underlying `Drawer` component.
   */
  drawerProps: _propTypes["default"].object,

  /**
   * Props to pass to the underlying `Sort` component.
   */
  sortProps: _propTypes["default"].object,

  /**
   * Text for the button label and the drawer header.  Defaults to "Sort".
   */
  title: _propTypes["default"].string,

  /**
   * The breakpoint in your theme below which a drawer UI should be used in favor of the menu UI.
   */
  drawerBreakpoint: _propTypes["default"].string,

  /**
   * When specified, clicking the button will navigate to the specified URL with a full page reload.
   */
  href: _propTypes["default"].string
};
SortButton.defaultProps = {
  title: 'Sort',
  drawerProps: {},
  sortProps: {},
  drawerBreakpoint: 'xs'
};

var _default = (0, _react.memo)(SortButton);

exports["default"] = _default;
//# sourceMappingURL=SortButton.js.map